@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert chords to Roman numeral notation
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 use Moo;
 use strictures 2;
@@ -88,7 +88,7 @@ Music::ToRoman - Convert chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.0100
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -112,13 +112,13 @@ C<Music::ToRoman> converts chords to Roman numeral notation.
 
 =head2 scale_note
 
-Note on which the scale is based.
+Note on which the scale is based.  This can be one of C, D, E, F, G, A or B.
 
 Default: C
 
 =head2 scale_name
 
-Name of the scale.
+Name of the scale.  See L<Music::Scales/SCALES> for the possible names.
 
 Default: major
 
@@ -142,7 +142,7 @@ L<Moo>
 
 L<List::MoreUtils>
 
-L<use Music::Scales>
+L<Music::Scales>
 
 L<https://en.wikipedia.org/wiki/Roman_numeral_analysis>
 
